# 基于局域网的文件分享平台

## Q: 现在要给同一个网络（例如：同一个学校）的人传大文件，某信又有大小限制，某云又有限速，怎么办呢？

PolarisHub就是解决该问题的最好方案。
1. 利用你的计算机作为一个局域网服务器，只需要把相应的文件拖进预先设定好的文件夹，或者删除相应的文件，即可管理你的共享文件。
2. 该程序将为你的平台自动生成一个网页，其他用户只要打开网页即可浏览所有文件。你也可以将文件网址分享给你的好友。
3. 任何处于同一局域网的用户只需要利用浏览器打开相关网站，或者手机扫码，即可获取对应文件。
4. 支持设置密码，禁止其他用户修改设置以及修改文件夹文件。
5. 分享完成之后，只需要关闭程序（注：不是关闭网页），即可断开连接。如果想保持连接，只需要保持程序一直运行即可。

## Q：如何安装使用呢？
a) 假如你装有Python3.6+：
1. pip install -r requirements.txt  //此步骤只需在第一次使用前执行一次
2. cd phub
3. python setup.py //按照提示设置默认目录，管理员密码等，此步骤只需在第一次使用前执行一次
4. python manage.py runserver 0.0.0.0:8000 //此步骤为开启服务，8000（端口号）可以替换为任意大于1000的整数，如修改，下面也要对应修改；如需停止服务，按 Ctrl + C 或者 Command + C 或者关闭整个终端即可。
5. 浏览器打开：http://localhost:8000/，即可看到你的服务了。
6. 其他人访问：http://你的IP:8000/。其中，你的IP可以在http://localhost:8000/中看到。注意：同一台计算机连接同一个局域网，IP将会不变。
7. 其他人也可以通过指定文件的url访问指定文件。

b) 假如你没有Python3.6+且为Windows系统：
1. 下载Release中的dist.zip压缩包并解压。
2. 双击setup.bat，按照提示设置默认目录，管理员密码等（此步骤只需在第一次使用前执行一次）。
3. 双击polarishub.bat，即可开启服务。此时端口号为8000，如需修改，只需修改bat中的8000数字即可，具体要求同a)4。
4~6. 同a)5\~7。

c) 假如你没有Python3.6+且为MacOS系统：
我们希望有使用MacOS的同学能把程序编译为MacOS可执行文件~

## Q：如何联系我？
有任何问题，欢迎在issues中留言~
